@@ -17,12 +17,10 @@
 #include "kjumpingcube_debug.h"
 #include <QFileDialog>
 #include <QTemporaryFile>
-#include <QRegExp>
 
 #include <KConfigDialog> // IDW test.
 #include <KIO/CopyJob>
 #include <KIO/Job>
-#include <kwidgetsaddons_version.h>
 #include <KJobWidgets>
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -352,7 +350,10 @@ void Game::doMove (int index)
    Q_EMIT setAction (UNDO, true);	// Update Undo and Redo actions.
    Q_EMIT setAction (REDO, false);
    m_steps->clear();
-   bool won = m_box->doMove (m_currentPlayer, index, nullptr, m_steps);
+#if AILog > 1
+   bool won =
+#endif
+   m_box->doMove (m_currentPlayer, index, nullptr, m_steps);
 #if AILog > 1
    qCDebug(KJUMPINGCUBE_LOG) << "GAME WON?" << won << "STEPS" << (* m_steps);
    // m_box->printBox();
@@ -564,12 +565,11 @@ void Game::saveGame (bool saveAs)
             return;
 
          // check filename
-         QRegExp pattern (QStringLiteral("*.kjc"), Qt::CaseSensitive, QRegExp::Wildcard);
-         if (! pattern.exactMatch (url.fileName())) {
+         if (! url.fileName().endsWith(QStringLiteral(".kjc"))) {
             url.setPath(url.path() + QLatin1String(".kjc"));
          }
 
-         KIO::StatJob* statJob = KIO::statDetails(url, KIO::StatJob::DestinationSide, KIO::StatNoDetails);
+         KIO::StatJob* statJob = KIO::stat(url, KIO::StatJob::DestinationSide, KIO::StatNoDetails);
          KJobWidgets::setWindow(statJob, m_view);
          if (statJob->exec()) {
             QString mes=i18n("The file %1 already exists.\n"
@@ -587,9 +587,9 @@ void Game::saveGame (bool saveAs)
    QTemporaryFile tempFile;
    tempFile.open();
    KConfig config (tempFile.fileName(), KConfig::SimpleConfig);
-   KConfigGroup main (&config, "KJumpingCube");
+   KConfigGroup main (&config, QStringLiteral("KJumpingCube"));
    main.writeEntry ("Version", KJUMPINGCUBE_VERSION_STRING);
-   KConfigGroup game (&config, "Game");
+   KConfigGroup game (&config, QStringLiteral("Game"));
    saveProperties (game);
    config.sync();
 
@@ -614,7 +614,8 @@ void Game::loadGame()
       url = QFileDialog::getOpenFileUrl (m_view, QString(), m_gameURL, QStringLiteral("*.kjc"));
       if (url.isEmpty())
          return;
-      KIO::StatJob* statJob = KIO::statDetails(url, KIO::StatJob::SourceSide, KIO::StatNoDetails);
+      KIO::StatJob* statJob = KIO::stat(url, KIO::StatJob::SourceSide, KIO::StatNoDetails);
+
       KJobWidgets::setWindow(statJob, m_view);
       if (! statJob->exec()) {
          QString mes = i18n("The file %1 does not exist!", url.url());
@@ -630,7 +631,7 @@ void Game::loadGame()
    job->exec();
    if (! job->error() ) {
       KConfig config( tempFile.fileName(), KConfig::SimpleConfig);
-      KConfigGroup main (&config, "KJumpingCube");
+      KConfigGroup main (&config, QStringLiteral("KJumpingCube"));
       if (! main.hasKey ("Version")) {
          QString mes = i18n("The file %1 is not a KJumpingCube gamefile!",
                             url.url());
@@ -639,7 +640,7 @@ void Game::loadGame()
       }
 
       m_gameURL = url;
-      KConfigGroup game (&config, "Game");
+      KConfigGroup game (&config, QStringLiteral("Game"));
       readProperties (game);
 
       Q_EMIT setAction (UNDO, false);
@@ -684,19 +685,11 @@ bool Game::newGameOK()
                    "Do you wish to abandon the current game?");
    }
    qCDebug(KJUMPINGCUBE_LOG) << "QUERY:" << query;
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
    int reply = KMessageBox::questionTwoActions (m_view,
-#else
-   int reply = KMessageBox::questionYesNo (m_view,
-#endif
                                            query, i18n("New Game?"),
                                            KGuiItem (i18n("Abandon Game")),
                                            KGuiItem (i18n("Continue Game")));
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
    if (reply == KMessageBox::PrimaryAction) {
-#else
-   if (reply == KMessageBox::Yes) {
-#endif
       qCDebug(KJUMPINGCUBE_LOG) << "ABANDON GAME";
       return true;			// Start a new game.
    }
